@@ -10,6 +10,8 @@
 #'  ensures the reproducibility of the result. See \code{\link{set.seed}} for
 #'  more details.
 #'@param method correlation coefficient, "pearson", "kendall", or "spearman".
+#'@param use a character string, the method regarding missing values. See
+#'  \code{\link{cor}} for more details.
 #'
 #'@return \code{XY} returns an one-row data frame with 2 columns:
 #'  \item{\code{cor}}{the correlation coefficient.} \item{\code{pval}}{the
@@ -21,16 +23,16 @@
 #' with(subset(ctm_Cu, run == "Jan"), XY(sediment, porewater))
 #'
 #'@export
-XY <- function(a, b, rand = 9999, seed = 1, method = c("pearson", "kendall", "spearman")) {
+XY <- function(a, b, rand = 9999, seed = 1, use = "everything", method = c("pearson", "kendall", "spearman")) {
 
     set.seed(seed)
 
-    cor_obs <- cor(a, b, method = method)
+    cor_obs <- cor(a, b, use = use, method = method)
 
     cor_rand <- rep(0, rand)
 
     for (i in 1:rand) {
-        cor_rand[i] <- cor(sample(a), b, method = method)
+        cor_rand[i] <- cor(sample(a), b, use = use, method = method)
     }
 
     pval <- (sum(abs(cor_rand) >= abs(cor_obs)) + 1) / (rand + 1)
