@@ -29,7 +29,8 @@
 #'  \item{\code{anova}}{anova table.} \item{\code{perm}}{permutation test
 #'  results with F-statistics, p-values, and strength of evidence.}
 #'
-#'@seealso \code{\link{lm}}, \code{\link{glmer}}, and \code{\link{lmer}}.
+#'@seealso \code{\link{lm}}, \code{\link[lme4]{glmer}}, and
+#'  \code{\link[lme4]{lmer}}.
 #'
 #'@references Manly, B. F. J. (2007). Randomization, bootstrap, and Monte Carlo
 #'  methods in biology (3rd ed). Chapman & Hall/ CRC. \cr \cr Ernst, M. D.
@@ -51,7 +52,7 @@
 #'
 #'@export
 #'
-tw_complex <- function(df, res, mains, nested, nuis, seed = 1, rand = 1999, emm = FALSE){
+tw_complex <- function(df, res, mains, nested, nuis, seed = 1, rand = 1999, emm = TRUE){
 
     set.seed(seed)
 
@@ -159,7 +160,7 @@ tw_complex <- function(df, res, mains, nested, nuis, seed = 1, rand = 1999, emm
     #obs_unit continuous
     if (!is.logical(df[, res]) & !missing(nested) & !missing(nuis)) {
 
-        TS_calc_lmer <- function(dataframe, response, main_factors, nested_factor, nuisance_var){
+        TS_calc_lmer1 <- function(dataframe, response, main_factors, nested_factor, nuisance_var){
 
             model <- suppressMessages(
                 lmer(
@@ -179,7 +180,7 @@ tw_complex <- function(df, res, mains, nested, nuis, seed = 1, rand = 1999, emm
             result
         }
 
-        TS_obs <- TS_calc_lmer(df, res, mains, nested, nuis)
+        TS_obs <- TS_calc_lmer1(df, res, mains, nested, nuis)
         F_obs <- TS_obs$anova[c(mains, paste(mains[1],":",mains[2], sep = "")), "F value"]
 
         F_rand <- matrix(rep(NA, rand*3), nrow = 3)
@@ -200,7 +201,7 @@ tw_complex <- function(df, res, mains, nested, nuis, seed = 1, rand = 1999, emm
                 df[, res][location]
             ); names(df_new) <- c(nested, mains, nuis, res)
 
-            TS_new <- TS_calc_lmer(df_new, res, mains, nested, nuis)
+            TS_new <- TS_calc_lmer1(df_new, res, mains, nested, nuis)
             F_new <- TS_new$anova[c(mains, paste(mains[1],":",mains[2], sep = "")), "F value"]
             F_rand[, i] <- F_new
         }
@@ -229,6 +230,78 @@ tw_complex <- function(df, res, mains, nested, nuis, seed = 1, rand = 1999, emm
 
     }
 
+    #obs_unit continuous no nuis
+    if (!is.logical(df[, res]) & !missing(nested) & missing(nuis)) {
+
+        TS_calc_lmer2 <- function(dataframe, response, main_factors, nested_factor){
+
+            model <- suppressMessages(
+                lmer(
+                    as.formula(
+                        paste(
+                            response, "~" , main_factors[1], "*" , main_factors[2], "+(1|" , nested_factor, ")"
+                        )
+                    ), data = dataframe)
+            )
+
+            result <- list(
+                # lmer = summary(model),
+                lmer = model,
+                anova = anova(model)
+            )
+
+            result
+        }
+
+        TS_obs <- TS_calc_lmer2(df, res, mains, nested)
+        F_obs <- TS_obs$anova[c(mains, paste(mains[1],":",mains[2], sep = "")), "F value"]
+
+        F_rand <- matrix(rep(NA, rand*3), nrow = 3)
+
+        nested_levels <- df[, nested] %>% unique
+
+        for (i in 1:rand) {
+            nested_levels_shuffle <- sample(nested_levels)
+
+            location <- sapply(nested_levels_shuffle, function(x){
+                which(df[, nested] == x)
+            })
+
+            df_new <- data.frame(
+                df[, nested][location],
+                df[mains],
+                df[, res][location]
+            ); names(df_new) <- c(nested, mains, res)
+
+            TS_new <- TS_calc_lmer2(df_new, res, mains, nested)
+            F_new <- TS_new$anova[c(mains, paste(mains[1],":",mains[2], sep = "")), "F value"]
+            F_rand[, i] <- F_new
+        }
+
+        if (emm) {
+            #EMM
+
+            emm_obs <- emmeans(TS_obs$lmer,
+                               as.formula(paste("~" , mains[1], "*" , mains[2])))
+            lmer_boot <- bootstrap_parameters(TS_obs$lmer, centrality = "mean")
+            emm_boot <- emmeans(lmer_boot,
+                                as.formula(paste("~" , mains[1], "*" , mains[2])))
+
+            emm_main1 <- suppressMessages(emmeans(TS_obs$lmer, as.formula(paste("~" , mains[1]))))
+            emm_main2 <- suppressMessages(emmeans(TS_obs$lmer, as.formula(paste("~" , mains[2]))))
+
+            #ES
+            sigma <- sigma(TS_obs$lmer)
+            edf <- df.residual(TS_obs$lmer)
+            es_main1 <- eff_size(emm_main1,
+                                 sigma, edf, method = "trt.vs.ctrl")
+            es_main2 <- eff_size(emm_main2,
+                                 sigma, edf, method = "trt.vs.ctrl")
+        }
+
+
+    }
+
 #report
 
 pval <- (rowSums(F_rand >= F_obs, na.rm = TRUE) + 1) / (rand + 1)
